﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

namespace ELTE.Web.TravelAgency
{
    public partial class Details : System.Web.UI.Page
    {

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!String.IsNullOrEmpty(Request["Building"]))
            {
                // megnézzük, hogy nem képbetöltésre használják-e az oldalt
                if (!String.IsNullOrEmpty(Request["Image"]))
                    // ha igen, akkor átadjuk a paramétereket a képbetöltéshez
                    LoadImage(Convert.ToInt32(Request["Building"]), Convert.ToInt32(Request["Image"]), !String.IsNullOrEmpty(Request["Size"]));
            }
            else
                Response.Redirect("Default.aspx");
        }

        /// <summary>
        /// Képbetöltés.
        /// </summary>
        /// <param name="buildingId">Épület azonosítója.</param>
        /// <param name="imageId">Kép azonosítója.</param>
        /// <param name="large">Nagy képet akarunk-e betölteni.</param>
        private void LoadImage(Int32 buildingId, Int32 imageId, Boolean large)
        {
            using (TravelAgencyEntities entities = new TravelAgencyEntities()) // az entitásmodellen keresztül töltjük be a tartalmat
            {
                BuildingImage image = null;
                try
                {
                    if (imageId > 0) // mennyiben konkrét képet töltünk be
                    {
                        image = entities.BuildingImage.Where(x => x.Id == imageId).FirstOrDefault(); // lekérdezzük az azonosító alapján
                    }
                    else // amennyiben csak az épülethez tartozó első képet akarjuk betölteni
                    {
                        image = entities.BuildingImage.Where(x => x.BuildingId == buildingId).FirstOrDefault(); // akkor az épület azonosító alapján lekérjük az első találatot
                    }
                }
                catch { }
                
                Response.Clear();
                Response.ContentType = "image/png"; // a váalsz egy kép lesz

                Byte[] imageBytes;
                if (image != null) // ha sikerült betölteni a képet
                {
                    if (large) // lekérdezzük a megfelelő méretben
                        imageBytes = image.ImageLarge;
                    else
                        imageBytes = image.ImageSmall;

                    Response.OutputStream.Write(imageBytes, 0, imageBytes.Length); // beírjuk a válaszba
                }

                Response.Flush();
            }
        }

        /// <summary>
        /// Tengerpart típus szöveges lekérdezése.
        /// </summary>
        /// <param name="number">Tengerpart azonosítója.</param>
        public String ToShoreType(Object number)
        {
            switch (Convert.ToInt32(number))
            {
                case 0: return "homokos";
                case 1: return "kavicsos";
                case 2: return "sziklás";
                default: return "(n/i)";
            }
        }

        /// <summary>
        /// Nap szöveges lekérdezése.
        /// </summary>
        /// <param name="number">Nap sorszáma.</param>
        public String ToDay(Object number)
        {
            switch (Convert.ToInt32(number)) 
            {
                case 1: return "hétfő";
                case 2: return "kedd";
                case 3: return "szerda";
                case 4: return "csütörtök";
                case 5: return "péntek";
                case 6: return "szombat";
                case 7: return "vasárnap";
                default: return "(n/i)";
            }
        }
    }
}